#ifndef NT2_INCLUDE_FUNCTIONS_LOG10_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOG10_HPP_INCLUDED

#include <nt2/exponential/include/functions/log10.hpp>

#endif
